__author__ = "Lukas Leufen"
__date__ = '2020-06-25'


import numpy as np


DEFAULT_STATIONS = ['DEBW107', 'DEBY081', 'DEBW013', 'DEBW076', 'DEBW087']
DEFAULT_VAR_ALL_DICT = {'o3': 'dma8eu', 'relhum': 'average_values', 'temp': 'maximum', 'u': 'average_values',
                        'v': 'average_values', 'no': 'dma8eu', 'no2': 'dma8eu', 'cloudcover': 'average_values',
                        'pblheight': 'maximum'}
DEFAULT_STATION_TYPE = "background"
DEFAULT_VARIABLES = DEFAULT_VAR_ALL_DICT.keys()
DEFAULT_START = "1997-01-01"
DEFAULT_END = "2017-12-31"
DEFAULT_WINDOW_HISTORY_SIZE = 13
DEFAULT_OVERWRITE_LOCAL_DATA = False
DEFAULT_OVERWRITE_LAZY_DATA = False
DEFAULT_HPC_LOGIN_LIST = ["ju", "hdfmll"]  # ju[wels} #hdfmll(ogin)
DEFAULT_HPC_HOST_LIST = ["jw", "hdfmlc"]  # first part of node names for Juwels (jw[comp], hdfmlc(ompute).
DEFAULT_CREATE_NEW_MODEL = True
DEFAULT_TRAIN_MODEL = True
DEFAULT_FRACTION_OF_TRAINING = 0.8
DEFAULT_EXTREME_VALUES = None
DEFAULT_EXTREMES_ON_RIGHT_TAIL_ONLY = False
DEFAULT_PERMUTE_DATA = False
DEFAULT_BATCH_SIZE = int(256 * 2)
DEFAULT_EPOCHS = 20
DEFAULT_EARLY_STOPPING_EPOCHS = np.inf
DEFAULT_RESTORE_BEST_MODEL_WEIGHTS = True
DEFAULT_TARGET_VAR = "o3"
DEFAULT_TARGET_DIM = "variables"
DEFAULT_WINDOW_LEAD_TIME = 3
DEFAULT_WINDOW_DIM = "window"
DEFAULT_TIME_DIM = "datetime"
DEFAULT_ITER_DIM = "Stations"
DEFAULT_DIMENSIONS = {"new_index": [DEFAULT_TIME_DIM, DEFAULT_ITER_DIM]}
DEFAULT_INTERPOLATION_METHOD = "linear"
DEFAULT_INTERPOLATION_LIMIT = 1
DEFAULT_TRAIN_START = "1997-01-01"
DEFAULT_TRAIN_END = "2007-12-31"
DEFAULT_TRAIN_MIN_LENGTH = 90
DEFAULT_VAL_START = "2008-01-01"
DEFAULT_VAL_END = "2009-12-31"
DEFAULT_VAL_MIN_LENGTH = 90
DEFAULT_TEST_START = "2010-01-01"
DEFAULT_TEST_END = "2017-12-31"
DEFAULT_TEST_MIN_LENGTH = 90
DEFAULT_TRAIN_VAL_MIN_LENGTH = 180
DEFAULT_USE_ALL_STATIONS_ON_ALL_DATA_SETS = True
DEFAULT_COMPETITORS = ["ols", "persi"]
DEFAULT_DO_UNCERTAINTY_ESTIMATE = True
DEFAULT_UNCERTAINTY_ESTIMATE_BLOCK_LENGTH = "1m"
DEFAULT_UNCERTAINTY_ESTIMATE_EVALUATE_COMPETITORS = True
DEFAULT_UNCERTAINTY_ESTIMATE_N_BOOTS = 1000
DEFAULT_DO_BIAS_FREE_EVALUATION = True
DEFAULT_EVALUATE_FEATURE_IMPORTANCE = True
DEFAULT_FEATURE_IMPORTANCE_CREATE_NEW_BOOTSTRAPS = False
DEFAULT_FEATURE_IMPORTANCE_N_BOOTS = 20
DEFAULT_FEATURE_IMPORTANCE_BOOTSTRAP_TYPE = "singleinput"
DEFAULT_FEATURE_IMPORTANCE_BOOTSTRAP_METHOD = "shuffle"
DEFAULT_PLOT_LIST = ["PlotMonthlySummary", "PlotStationMap", "PlotClimatologicalSkillScore", "PlotTimeSeries",
                     "PlotCompetitiveSkillScore", "PlotFeatureImportanceSkillScore", "PlotConditionalQuantiles",
                     "PlotAvailability", "PlotAvailabilityHistogram", "PlotDataHistogram", "PlotPeriodogram",
                     "PlotSampleUncertaintyFromBootstrap", "PlotErrorMetrics", "PlotDataMonthlyDistribution",
                     "PlotTimeEvolutionMetric", "PlotSeasonalMSEStack", "PlotErrorsOnMap"]
DEFAULT_SAMPLING = "daily"
DEFAULT_DATA_ORIGIN = {"cloudcover": "REA", "humidity": "REA", "pblheight": "REA", "press": "REA", "relhum": "REA",
                       "temp": "REA", "totprecip": "REA", "u": "REA", "v": "REA", "no": "", "no2": "", "o3": "",
                       "pm10": "", "so2": ""}
DEFAULT_USE_MULTIPROCESSING = True
DEFAULT_USE_MULTIPROCESSING_ON_DEBUG = False
DEFAULT_MAX_NUMBER_MULTIPROCESSING = 16
DEFAULT_CREATE_SNAPSHOT = False


def get_defaults():
    """Return all default parameters set in defaults.py"""
    return {key: value for key, value in globals().items() if key.startswith('DEFAULT')}


if __name__ == "__main__":
    print(get_defaults())
